import argparse
import webbrowser

import colorama
from colorama import Fore

from . import scraper


def print_data(data) :
    for num, i in enumerate(data, start=1) :
        title = Fore.BLUE + i["title"]
        store = Fore.YELLOW + i["store"]

        print(f"{num}. {title} - {store}")


def open_browser(master_list, inputs_list) :

    inputs_list = inputs_list.replace(" ", "").split(",") # remove all spaces then split all choices

    for num_choice in inputs_list :
        if "-" in num_choice :
            start, end = num_choice.split("-")

            slicing = slice(int(start)-1, int(end))
            sliced_games = master_list[slicing]
            [webbrowser.open_new_tab(game["url"]) for game in sliced_games]

        else :
            webbrowser.open_new_tab(master_list[int(num_choice) - 1]["url"])

def main() :
    colorama.init(autoreset=True)

    parser = argparse.ArgumentParser(description="Scrape and show limited free games")

    parser.add_argument("-v", "--view-only", action="store_true", help="List the games without waiting for input to open website")
    parser.add_argument("-tp", "--twitch-prime",action="store_true", help="Show twitch prime/prime gaming limited free games")

    args = parser.parse_args()

    free_games = scraper.extract()
    free_games = sorted(free_games, key=lambda x : x["store"])

    if args.twitch_prime == False :
        free_games = [i for i in free_games if i["store"] != "amazon.com"]

    print_data(free_games)

    if args.view_only == False:
        input_choice = input("\nChoose game(s) :")
        open_browser(free_games, input_choice)

if __name__ == "__main__":
    main()


import json

from bs4 import BeautifulSoup
import requests
import tldextract

def extract():
    """ 
    Scrape data on https://isthereanydeal.com/specials/ 
    
    """
    freegames = []
    url = "https://isthereanydeal.com/specials/"

    headers = {
        'User-Agent': "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7",
    }

    response = requests.get(url, headers=headers).text

    soup = BeautifulSoup(response, features="lxml")
    bundle = soup.find_all("div", attrs={"class" : "bundle-row1"})
    for i in bundle :
        
        bundle_title = i.find("div", attrs={"class" : "bundle-title"})
        bundle_tag = i.find("a", attrs={"class" : "bundle-tag"}).text
        
        if bundle_tag == "giveaway" :
            
            time_left = i.find("div", attrs={"class" : "bundle-time"}).text

            if "unknown" in time_left: 
                continue # search only for limited time free games       

            title = str(bundle_title.text).split("-")[0].strip() # extract the game title from whitespaces
            url = bundle_title.find("a", attrs={"href" : True})["href"]
            store = tldextract.extract(url).registered_domain
   
            freegames.append({"title" : title, "url" : url, "store" : store,"time_left" : time_left})
    
    return freegames



if __name__ == "__main__":
    print(extract())



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="freeg",
    version="0.1.1",
    author="refk32",
    author_email="refk32@gmail.com",
    description="Scrape limited free games",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/refk32/freeg",
    packages=setuptools.find_packages(),
    install_requires=[            
          'requests',
          'beautifulsoup4',
          'tldextract',
          'colorama',
          'lxml'
        ],
    entry_points={
        "console_scripts" : [
            "freeg = freeg.freeg_cli:main"
        ],

    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop"
    ],
    python_requires='>=3.6',
)
